@@ -9,8 +9,9 @@
  * Copyright (C) 2001 Eazel, Inc.
  */
 
-#include "config.h"
-#include "bonobo-ui-toolbar-control-item.h"
+#include <config.h>
+#include <bonobo/bonobo-ui-private.h>
+#include <bonobo/bonobo-ui-toolbar-control-item.h>
 
 #include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-property-bag-client.h>
@@ -284,7 +285,7 @@ bonobo_ui_toolbar_control_item_get_type (void)
 static void
 proxy_activate_cb (GtkWidget *button, GtkObject *item)
 {
-	gtk_signal_emit_by_name (item, "activate");
+	g_signal_emit_by_name (item, "activate");
 }
 
 GtkWidget *
@@ -304,7 +305,7 @@ bonobo_ui_toolbar_control_item_construct (
         priv->eventbox = gtk_event_box_new ();
         priv->box      = gtk_vbox_new (FALSE, 0);
 	
-	gtk_signal_connect (GTK_OBJECT (priv->button), "activate",
+	g_signal_connect (GTK_OBJECT (priv->button), "activate",
 			    (GtkSignalFunc) proxy_activate_cb, control_item);
 	
 	gtk_container_add (GTK_CONTAINER (priv->box),
@@ -327,14 +328,14 @@ bonobo_ui_toolbar_control_item_new (Bonobo_Control control_ref)
         BonoboUIToolbarControlItem *control_item;
 	GtkWidget *ret;
 
-        control_item = gtk_type_new (
-                bonobo_ui_toolbar_control_item_get_type ());
+        control_item = g_object_new (
+                bonobo_ui_toolbar_control_item_get_type (), NULL);
 
         ret = bonobo_ui_toolbar_control_item_construct (
 		control_item, control_ref);
 
 	if (!ret)
-		g_object_unref (G_OBJECT (control_item));
+		g_object_unref (control_item);
 
 	return ret;
 }
@@ -349,3 +350,22 @@ bonobo_ui_toolbar_control_item_set_display (BonoboUIToolbarControlItem    *item,
 	item->priv->hdisplay = hdisplay;
 	item->priv->vdisplay = vdisplay;
 }
+
+void
+bonobo_ui_toolbar_control_item_set_sensitive (BonoboUIToolbarControlItem *item,
+					      gboolean                    sensitive)
+{
+	gboolean changed;
+
+	g_return_if_fail (BONOBO_IS_UI_TOOLBAR_CONTROL_ITEM (item));
+
+	changed = (( GTK_WIDGET_IS_SENSITIVE (item) && !sensitive) ||
+		   (!GTK_WIDGET_IS_SENSITIVE (item) &&  sensitive));
+
+	if (!changed || !item->priv->control)
+		return;
+
+	bonobo_control_frame_control_set_state (
+		bonobo_widget_get_control_frame (item->priv->control),
+		sensitive ? Bonobo_Gtk_StateNormal : Bonobo_Gtk_StateInsensitive);
+}
